@@ -59,7 +59,8 @@ step_count <- function(recipe,
                        normalize = FALSE,
                        options = list(),
                        result = make.names(pattern),
-                       input = NULL) {
+                       input = NULL,
+                       skip = FALSE) {
   if (!is.character(pattern))
     stop("`pattern` should be a character string", call. = FALSE)
   if (length(pattern) != 1)
@@ -70,7 +71,7 @@ step_count <- function(recipe,
          paste0(valid_args, collapse = ", "),
          call. = FALSE)
 
-  terms <- check_ellipses(...)
+  terms <- ellipse_check(...)
   if (length(terms) > 1)
     stop("For this step, only a single selector can be used.", call. = FALSE)
 
@@ -84,7 +85,8 @@ step_count <- function(recipe,
       normalize = normalize,
       options = options,
       result = result,
-      input = input
+      input = input,
+      skip = skip
     )
   )
 }
@@ -96,7 +98,8 @@ step_count_new <- function(terms = NULL,
                            normalize = NULL,
                            options = NULL,
                            result = NULL,
-                           input = NULL) {
+                           input = NULL,
+                           skip = FALSE) {
   step(
     subclass = "count",
     terms = terms,
@@ -106,7 +109,8 @@ step_count_new <- function(terms = NULL,
     normalize = normalize,
     options = options,
     result = result,
-    input = input
+    input = input,
+    skip = skip
   )
 }
 
@@ -126,7 +130,8 @@ prep.step_count <- function(x, training, info = NULL, ...) {
     normalize = x$normalize,
     options = x$options,
     input = col_name,
-    result = x$result
+    result = x$result,
+    skip = x$skip
   )
 }
 
