@@ -38,8 +38,8 @@ recipe.default <- function(x, ...)
 #'   \item{term_info}{A tibble that contains the current set of terms in the
 #'   data set. This initially defaults to the same data contained in
 #'   `var_info`.}
-#'   \item{steps}{A list of `step` objects that define the sequence of
-#'   preprocessing steps that will be applied to data. The default value is
+#'   \item{steps}{A list of `step`  or `check` objects that define the sequence of
+#'   preprocessing operations that will be applied to data. The default value is
 #'   `NULL`}
 #'   \item{template}{A tibble of the data. This is initialized to be the same
 #'   as the data given in the `data` argument but can be different after
@@ -60,14 +60,19 @@ recipe.default <- function(x, ...)
 #'   which variables in a data set should be used and then sequentially
 #'   defining their roles (see the last example).
 #'
-#' Steps to the recipe can be added sequentially. Steps can include common
-#'   operations like logging a variable, creating dummy variables or
-#'   interactions and so on. More computationally complex actions such as
-#'   dimension reduction or imputation can also be specified.
+#' There are two different types of operations that can be
+#'  sequentially added to a recipe. **Steps**  can include common
+#'  operations like logging a variable, creating dummy variables or
+#'  interactions and so on. More computationally complex actions
+#'  such as dimension reduction or imputation can also be specified.
+#'  **Checks** are operations that conduct specific tests of the
+#'  data. When the test is satisfied, the data are returned without
+#'  issue or modification. Otherwise, any error is thrown.
 #'
 #' Once a recipe has been defined, the [prep()] function can be
-#'   used to estimate quants required in the steps from a data set (a.k.a. the
-#'   training data). [prep()] returns another recipe.
+#'  used to estimate quantities required for the operations using a
+#'  data set (a.k.a. the training data). [prep()] returns another
+#'  recipe.
 #'
 #' To apply the recipe to a data set, the [bake()] function is
 #'   used in the same manner as `predict` would be for models. This
@@ -232,7 +237,7 @@ form2args <- function(formula, data, ...) {
   if (!is_formula(formula))
     formula <- as.formula(formula)
   ## check for in-line formulas
-  check_elements(formula, allowed = NULL)
+  element_check(formula, allowed = NULL)
 
   if (!is_tibble(data))
     data <- as_tibble(data)
@@ -240,7 +245,7 @@ form2args <- function(formula, data, ...) {
   ## use rlang to get both sides of the formula
   outcomes <- get_lhs_vars(formula, data)
   predictors <- get_rhs_vars(formula, data, no_lhs = TRUE)
-  
+
   ## if . was used on the rhs, subtract out the outcomes
   predictors <- predictors[!(predictors %in% outcomes)]
 
@@ -274,38 +279,39 @@ prep   <- function(x, ...)
 
 #' Train a Data Recipe
 #'
-#' For a recipe with at least one preprocessing step, estimate the required
+#' For a recipe with at least one preprocessing operation, estimate the required
 #'   parameters from a training set that can be later applied to other data
 #'   sets.
 #' @param training A data frame or tibble that will be used to estimate
 #'   parameters for preprocessing.
-#' @param fresh A logical indicating whether already trained steps should be
+#' @param fresh A logical indicating whether already trained operation should be
 #'   re-trained. If `TRUE`, you should pass in a data set to the argument
 #'   `training`.
-#' @param verbose A logical that controls wether progress is reported as steps
+#' @param verbose A logical that controls wether progress is reported as operations
 #'   are executed.
-#' @param retain A logical: should the *preprocessingcessed* training set be saved
+#' @param retain A logical: should the *preprocessed* training set be saved
 #'   into the `template` slot of the recipe after training? This is a good
 #'     idea if you want to add more steps later but want to avoid re-training
-#'     the existing steps.
+#'     the existing steps. Also, it is advisable to use `retain = TRUE`
+#'     if any steps use the option `skip = FALSE`.
 #' @param stringsAsFactors A logical: should character columns be converted to
-#'   factors? This affects the preprocessingcessed training set (when
+#'   factors? This affects the preprocessed training set (when
 #'   `retain = TRUE`) as well as the results of `bake.recipe`.
 #' @return A recipe whose step objects have been updated with the required
 #'   quantities (e.g. parameter estimates, model objects, etc). Also, the
-#'   `term_info` object is likely to be modified as the steps are
+#'   `term_info` object is likely to be modified as the operations are
 #'   executed.
 #' @details Given a data set, this function estimates the required quantities
-#'   and statistics required by any steps.
+#'   and statistics required by any operations.
 #'
 #' [prep()] returns an updated recipe with the estimates.
 #'
 #' Note that missing data handling is handled in the steps; there is no global
-#'   `na.rm` option at the recipe-level or in  [prep()].
+#'   `na.rm` option at the recipe-level or in [prep()].
 #'
 #' Also, if a recipe has been trained using [prep()] and then steps
-#'   are added, [prep()] will only update the new steps. If
-#'   `fresh = TRUE`, all of the steps will be (re)estimated.
+#'   are added, [prep()] will only update the new operations. If
+#'   `fresh = TRUE`, all of the operations will be (re)estimated.
 #'
 #' As the steps are executed, the `training` set is updated. For example,
 #'   if the first step is to center the data and the second is to scale the
@@ -313,6 +319,7 @@ prep   <- function(x, ...)
 #'
 #' @rdname prep
 #' @importFrom tibble as_tibble is_tibble tibble
+#' @importFrom purrr map_lgl
 #' @export
 prep.recipe <-
   function(x,
@@ -341,19 +348,28 @@ prep.recipe <-
     } else
       lvls <- NULL
 
+    # The only way to get the results for skipped steps is to
+    # use `retain = TRUE` so issue a warning if this is not the case
+    skippers <- map_lgl(x$steps, is_skipable)
+    if (any(skippers) & !retain)
+      warning("Since some operations have `skip = FALSE`, using ",
+              "`retain = TRUE` will allow those steps results to ",
+              "be accessible.")
+
+
     for (i in seq(along = x$steps)) {
-      note <- paste("step", i, gsub("^step_", "", class(x$steps[[i]])[1]))
+      note <-
+        paste("oper",  i, gsub("_", " ", class(x$steps[[i]])[1]))
       if (!x$steps[[i]]$trained | fresh) {
         if (verbose)
-          cat(note, "training", "\n")
-
+          cat(note, "[training]", "\n")
         # Compute anything needed for the preprocessing steps
         # then apply it to the current training set
 
         x$steps[[i]] <-
           prep(x$steps[[i]],
-                  training = training,
-                  info = x$term_info)
+               training = training,
+               info = x$term_info)
         training <- bake(x$steps[[i]], newdata = training)
         x$term_info <-
           merge_term_info(get_types(training), x$term_info)
@@ -398,23 +414,23 @@ bake <- function(object, ...)
 
 #' Apply a Trained Data Recipe
 #'
-#' For a recipe with at least one preprocessing step that has been trained by
+#' For a recipe with at least one preprocessing operations that has been trained by
 #'   [prep.recipe()], apply the computations to new data.
 #' @param object A trained object such as a [recipe()] with at least
-#'   one preprocessing step.
+#'   one preprocessing operation.
 #' @param newdata A data frame or tibble for whom the preprocessing will be
 #'   applied.
 #' @param ... One or more selector functions to choose which variables will be
 #'   returned by the function. See [selections()] for more details.
 #'   If no selectors are given, the default is to use
 #'   [everything()].
-#' @param composition Either "tibble" or "dgCMatrix" for the
+#' @param composition Either "tibble", "matrix", or "dgCMatrix" for the
 #'  format of the processed data set. Note that all computations
 #'  during the baking process are done in a non-sparse format. Also,
 #'  note that this argument should be called **after** any selectors
 #'  and the selectors should only resolve to numeric columns
 #'  (otherwise an error is thrown).
-#' @return A tibble or sparse matrix that may have different
+#' @return A tibble, matrix, or sparse matrix that may have different
 #'  columns than the original columns in `newdata`.
 #' @details [bake()] takes a trained recipe and applies the
 #'   operations to a data set to create a design matrix.
@@ -424,6 +440,10 @@ bake <- function(object, ...)
 #'  of [prep()] to avoid duplicating the same operations. With this
 #'  option set, [juice()] can be used instead of `bake` with
 #'  `newdata` equal to the training set.
+#'
+#' Also, any steps with `skip = TRUE` will not be applied to the
+#'   data when `bake` is invoked. [juice()] will always have all
+#'   of the steps applied.
 #' @seealso [recipe()], [juice()], [prep()]
 #' @rdname bake
 #' @importFrom tibble as_tibble
@@ -436,7 +456,7 @@ bake.recipe <- function(object, newdata, ..., composition = "tibble") {
     stop("`composition` should be one of: ",
          paste0("'", formats, "'", collapse = ","),
          call. = FALSE)
-  
+
   if (!is_tibble(newdata)) newdata <- as_tibble(newdata)
 
   terms <- quos(...)
@@ -447,13 +467,15 @@ bake.recipe <- function(object, newdata, ..., composition = "tibble") {
   keepers <- terms_select(terms = terms, info = object$term_info)
 
   for (i in seq(along = object$steps)) {
-    newdata <- bake(object$steps[[i]], newdata = newdata)
-    if (!is_tibble(newdata)) newdata <- as_tibble(newdata)
+    if (!is_skipable(object$steps[[i]])) {
+      newdata <- bake(object$steps[[i]], newdata = newdata)
+      if (!is_tibble(newdata))
+        newdata <- as_tibble(newdata)
+    }
   }
 
   newdata <- newdata[, names(newdata) %in% keepers]
-
-  ## the Levels are not null when no nominal data are present or
+  ## The levels are not null when no nominal data are present or
   ## if stringsAsFactors = FALSE in `prep`
   if (!is.null(object$levels)) {
     var_levels <- object$levels
@@ -466,9 +488,12 @@ bake.recipe <- function(object, newdata, ..., composition = "tibble") {
       newdata <- strings2factors(newdata, var_levels)
   }
 
-  if(composition == "dgCMatrix")
-    newdata <- convert_dgCMatrix(newdata)
-  
+  if (composition == "dgCMatrix") {
+    newdata <- convert_matrix(newdata, sparse = TRUE)
+  } else if (composition == "matrix") {
+    newdata <- convert_matrix(newdata, sparse = FALSE)
+  }
+
   newdata
 }
 
@@ -513,7 +538,7 @@ print.recipe <- function(x, form_width = 30, ...) {
           "\n")
   }
   if (!is.null(x$steps)) {
-    cat("\nSteps:\n\n")
+    cat("\nOperations:\n\n")
     for (i in seq_along(x$steps))
       print(x$steps[[i]], form_width = form_width)
   }
@@ -532,7 +557,7 @@ print.recipe <- function(x, form_width = 30, ...) {
 #'   used).
 #' @return A tibble with columns `variable`, `type`, `role`,
 #'   and `source`.
-#' @details Note that, until the recipe has been trained, the currrent and
+#' @details Note that, until the recipe has been trained, the current and
 #'   original variables are the same.
 #' @examples
 #' rec <- recipe( ~ ., data = USArrests)
@@ -557,12 +582,17 @@ summary.recipe <- function(object, original = FALSE, ...) {
 #'  applied to the training set. Rather than running `bake`
 #'  to duplicate this processing, this function will return
 #'  variables from the processed training set.
-#' @inheritParams bake.recipe 
+#' @inheritParams bake.recipe
 #' @param object A `recipe` object that has been prepared
 #'   with the option `retain = TRUE`.
 #' @details When preparing a recipe, if the training data set is
 #'  retained using `retain = TRUE`, there is no need to `bake` the
 #'  recipe to get the preprocessed training set.
+#'
+#'  `juice` will return the results of a recipes where _all steps_
+#'  have been applied to the data, irrespective of the value of
+#'  the step's `skip` argument.
+#'
 #' @examples
 #' data(biomass)
 #'
@@ -593,12 +623,12 @@ juice <- function(object, ..., composition = "tibble") {
   if(!all(tr_steps))
     stop("At least one step has not be prepared; cannot extract.",
          call. = FALSE)
-  
+
   if (!any(composition == formats))
     stop("`composition` should be one of: ",
          paste0("'", formats, "'", collapse = ","),
          call. = FALSE)
-  
+
   terms <- quos(...)
   if (is_empty(terms))
     terms <- quos(everything())
@@ -617,13 +647,16 @@ juice <- function(object, ..., composition = "tibble") {
     if (length(var_levels) > 0)
       newdata <- strings2factors(newdata, var_levels)
   }
-  
-  if(composition == "dgCMatrix")
-    newdata <- convert_dgCMatrix(newdata)
-  
+
+  if (composition == "dgCMatrix") {
+    newdata <- convert_matrix(newdata, sparse = TRUE)
+  } else if (composition == "matrix") {
+    newdata <- convert_matrix(newdata, sparse = FALSE)
+  }
+
   newdata
 }
 
-formats <- c("tibble", "dgCMatrix")
+formats <- c("tibble", "dgCMatrix", "matrix")
 
 
