@@ -8,13 +8,16 @@ okc_rec <- recipe(~ ., data = okc) %>%
   step_other(all_nominal(), threshold = 0.05) %>%
   step_date(date, features = "dow") %>%
   step_center(all_numeric()) %>%
-  step_dummy(all_nominal())
+  step_dummy(all_nominal()) %>%
+  check_cols(starts_with("date"))
 
 test_that('untrained', {
   exp_res_1 <- tibble(
-    number = 1:4,
-    type = c("other", "date", "center", "dummy"),
-    trained = rep(FALSE, 4)
+    number = 1:5,
+    operation = c("step", "step", "step", "step", "check"),
+    type = c("other", "date", "center", "dummy", "cols"),
+    trained = rep(FALSE, 5),
+    skip = rep(FALSE, 5)
   )
   expect_equal(tidy(okc_rec), exp_res_1)
 })
@@ -22,9 +25,11 @@ test_that('untrained', {
 
 test_that('trained', {
   exp_res_2 <- tibble(
-    number = 1:4,
-    type = c("other", "date", "center", "dummy"),
-    trained = rep(TRUE, 4)
+    number = 1:5,
+    operation = c("step", "step", "step", "step", "check"),
+    type = c("other", "date", "center", "dummy", "cols"),
+    trained = rep(TRUE, 5),
+    skip = rep(FALSE, 5)
   )
   trained <- prep(okc_rec, training = okc)
   expect_equal(tidy(trained), exp_res_2)
